angular.module('selae.core.controllers')

.controller('NotificationsCtrl', ['$scope','popupSrv', '$timeout','$ionicHistory','mobileSrv','$rootScope','storageProvider', 'analyticsSrv',
 function($scope,popupSrv, $timeout, $ionicHistory, mobileSrv, $rootScope, storageProvider, analyticsSrv) {
 	$scope.$on('$ionicView.beforeEnter', function (event, viewData) {
		viewData.enableBack = true;
	});

	$rootScope.$on("notifStateChange", function(){
		$scope.notificationBlocked = false;
		$scope.$apply();
	});

	if (window.ga !== undefined) { analyticsSrv.trackView('Ajustes Configuración'); }

	var properties = $rootScope.selae.properties;

	 $scope.notifications = {};
	 var promiseGetReceiveNotifications = storageProvider.getData(storageProvider.KEY_STORAGE_PUSHENABLED);
	 promiseGetReceiveNotifications.then(
		 function(receiveNotifications){
			Console.logGreen('get de las notificaciones: ', receiveNotifications);
			$scope.notifications.enable = receiveNotifications == "true" || receiveNotifications == "1";
			$scope.notificationBlocked = false;
		 },
		 function(error){
			Console.logPurple('Fracaso al cargar KEY_STORAGE_PUSHENABLED - notificationsCtrl.js', error);
			//Las notificaciones en caso de error las dejamos activadas.
			$scope.notifications.enable = true;
			$scope.notificationBlocked = false;
		 }
	 );

	 //Habilita las notificaciones y guarda el estado con el storage.provider.
	function enableNotifications(){
		//Aquí antes había una recuperación de los datos de la bbdd, pero NO es necesario.
		//Este método se invoca desde el watcher, luego salta bajo una acción del usuario
		//o con la consulta que hace en la carga. Pero aquí no se necesita una segunda comprobación de
		//la bbdd, es completamente redundante.
		//Guardamos
		var promiseSetNotificationsEnabled = storageProvider.setData(storageProvider.KEY_STORAGE_PUSHENABLED, "true");
		promiseSetNotificationsEnabled.then(
			function(exito){
				Console.logGreen('Éxito al guardar KEY_STORAGE_PUSHENABLED - notificationsCtrl.js', exito);
			},
			function(error){
				Console.logPurple('Fracaso al guardar KEY_STORAGE_PUSHENABLED - notificationsCtrl.js', error);
			}
		);
		//Activamos
		BMA4S.setPushEnabled(true);
		console.log($scope.notifications);
	}

	//Deshabilita las notificaciones y guarda esta deshabilitación en el storage.provider.
	function disableNotifications(){
		//Aquí antes había una recuperación de los datos de la bbdd, pero NO es necesario.
		//Este método se invoca desde el watcher, luego salta bajo una acción del usuario
		//o con la consulta que hace en la carga. Pero aquí no se necesita una segunda comprobación de
		//la bbdd, es completamente redundante.
		//Guardamos
		var promiseSetNotificationsDisabled = storageProvider.setData(storageProvider.KEY_STORAGE_PUSHENABLED, "false");
		promiseSetNotificationsDisabled.then(
			function(exito){
				Console.logGreen('Éxito al guardar KEY_STORAGE_PUSHENABLED - notificationsCtrl.js', exito);
			},
			function(error){
				Console.logPurple('Fracaso al guardar KEY_STORAGE_PUSHENABLED - notificationsCtrl.js', error);
			}
		);
		//Desactivamos
		BMA4S.setPushEnabled(false);
		console.log($scope.notifications);
	}

	//Este watcher antes estaba dentro de la recepción de la promesa con el estado
	//de las notificaciones PUSH, realmente no es necesario. Puede ir fuera porque salta con la
	//acción del usuario sobre le botón.
	$scope.$watch('notifications.enable',function(newValue, oldValue){
		// console.log(newValue);
		if (window.ga) {
			analyticsSrv.trackEvent('Ajustes', 'Notificaciones', 'Notificaciones');
		}
			if (newValue === true){
				enableNotifications();
			}
			else if (newValue === false){
				disableNotifications();
			}
		});
	
	// Compueba si hay huella registrada para activar o no el check
	$scope.fingerprint = { active: false, avalible: false };
	try {
		if (ionic.Platform.isAndroid()) {
        	rootdetection.isDeviceRooted(function (result) {
            	if (!result) {
					window.plugins.touchid.isAvailable(function() {
						$scope.fingerprint.available = true;
						var promiseGetClaveAndroid = storageProvider.getData(storageProvider.KEY_STORAGE_CLAVE);
						promiseGetClaveAndroid.then(
							function(theClave){
								window.plugins.touchid.has(theClave, function() {
									$scope.fingerprint.active = true;
								});
							},
							function(error){
								Console.logPurple('Fracaso al cargar KEY_STORAGE_CLAVE Android - notificationsCtrl.js', error);
								$scope.fingerprint.active = false;
							}
						);
					});
            	}
        	}, null);
        } else if (ionic.Platform.isIOS()) {
        	jailbreakdetection.isJailbroken(function (result) {
            	if (!result) {
					window.plugins.touchid.isAvailable(function() {
						$timeout(function() {
							$scope.fingerprint.available = true;
						});
						var promiseGetClaveIOS = storageProvider.getData(storageProvider.KEY_STORAGE_CLAVE);
						promiseGetClaveIOS.then(
							function(theClave){
								if (!theClave) {theClave = '';}
								window.plugins.touchid.has(theClave, function() {
									$timeout(function() {
										$scope.fingerprint.active = true;
									});
								});
							},
							function(error){
								Console.logPurple('Fracaso al cargar KEY_STORAGE_CLAVE iOS - notificationsCtrl.js', error);
								$scope.fingerprint.active = false;
							}
						);
					});
        		}
        	}, null);
    	}
	} catch(e) {console.error(e);}


	// Esta funcion se ejecuta al hcer click sobre el checkbox de la huella
	// OJO! el estado del check que viene a traves de la funcion no es el actual, si no el que vendra en el futuro. 
	$scope.changeFingerprint = function() {
		if (window.ga) {
			analyticsSrv.trackEvent('Ajustes', 'Autenticación por huella', 'Autenticación por huella');
		};
		
		if (!$scope.fingerprint.active) {
			var promiseChangeFingerprint = storageProvider.getData(storageProvider.KEY_STORAGE_CLAVE);
			promiseChangeFingerprint.then(
				function(theclave){
					window.plugins.touchid.delete(theclave, function() {
						console.log('Huella borrada');
					}, function() { popupSrv.showErrorPopup('Se produjo un error al desactivar la huella'); });
				},
				function(error){
					Console.logPurple('Fracaso al cargar KEY_STORAGE_CLAVE - notificationsCtrl.js', error);
				}
			);
		} else { 
			event.preventDefault();
			popupSrv.showErrorPopup('Vuelva a logearse con su huella para vincularla');
		}
	};

}]);
