angular.module('selae.core.services')
.factory('uuidProvider', ['$q', 'storageProvider', function($q, storageProvider){

    /**
     * Devuelve un UUID en formato string mediante una promesa.
     * Este UUID permanece constante porque se guarda en el storafe provider.
     * Si se borran los datos de usuario, se borrarán los UUID.
     */
    this.getUUID = function(){
        var result = $q.defer();

        //tenemos uno guardado para que devuelva siempre el mismo?
        var promiseGetUUID = storageProvider.getData(storageProvider.KEY_UUID);
        promiseGetUUID.then(
            function(uuid){
                if(uuid != null){
                    //sí, pues lo devolvemos.
                    console.log('UUID previamente almacenado: ' + uuid);
                    result.resolve(uuid);
                }else{
                    //No se tenía uno almacenado, se genera uno.
                    uuid = getRandomUUID();
                    if(uuid != null){
                        //estupendo, ya tenemos uno. Lo guardamos para la próxima.
                        var promiseSetUUID = storageProvider.setData(storageProvider.KEY_UUID, uuid);
                        promiseSetUUID.then(
                            function(exito){
                                //Guardado y ahora a devolverlo a la capa superior.
                                console.log('UUID almacenado: ' + exito);
                                result.resolve(exito);
                            },
                            function(errorGrave){
                                //Generado, pero no guardado. No podemos devolverlo porque la próxima sería otro
                                //a la capa superior.
                                console.log('Error al almacenar UUID: ' + errorGrave);
                                result.reject(errorGrave);
                            }
                        );
                    }else{
                        //No se ha podido generar, se devuelve error.
                        result.reject('uuid generado null');
                    }
                }
            },
            function(error){
                result.reject(error);
            }
        );

        return result.promise;
    };

    /**
     * Genera UUIDs aleatorios.
     * Esto es una copia del getRandomUUID de SELAE Cartera de Boletos.
     */
    getRandomUUID = function(){
        //Ejemplo '550e8400-e29b-41d4-a716-446655440000'
        var result = '';
        var allowedChars = '0123456789abcdef';
        var allowedChars3 = '34';
        var allowedChars4 = '89ab';

        //Primera tupla.
        var partLength = 8;
        for (var i = partLength; i > 0; --i) result += allowedChars[Math.floor(Math.random() * allowedChars.length)];
        result += '-';

        //Segunda tupla.
        partLength = 4;
        for (i = partLength; i > 0; --i) result += allowedChars[Math.floor(Math.random() * allowedChars.length)];
        result += '-';

        //Tercera tupla.
        //Cambio, la tercera tupla debe empezar por 3 o por 4
        result += allowedChars3[Math.floor(Math.random() * allowedChars3.length)];
        partLength = 3;
        for ( i = partLength; i > 0; --i) result += allowedChars[Math.floor(Math.random() * allowedChars.length)];
        result += '-';

        //Cuarta tupla.
        //Cambio, la cuarta tupla debe empezar por 8,9,a o b
        result += allowedChars4[Math.floor(Math.random() * allowedChars4.length)];
        partLength = 3;
        for ( i = partLength; i > 0; --i) result += allowedChars[Math.floor(Math.random() * allowedChars.length)];
        result += '-';

        //Quinta tupla.
        partLength = 12;
        for ( i = partLength; i > 0; --i) result += allowedChars[Math.floor(Math.random() * allowedChars.length)];

        return result;
    };

    return{
        getUUID: this.getUUID,
        getRandomUUID: this.getRandomUUID
    };
}]);