angular
    .module('selae.user.controllers')
    .controller('UserProfileCtrl', UserProfileCtrl);
    
    UserProfileCtrl.$inject = [
        '$rootScope', 
        '$http', 
        '$filter', 
        'popupSrv', 
        'requestSrv', 
        'config',
        '$state'
    ];

    function UserProfileCtrl( $rootScope, $http, $filter, popupSrv, requestSrv, config, $state) {
        'use strict';

        var vm = this;

        popupSrv.showLoading('Comprobando datos');

        vm.verificateCall = function(plugin) {
            // Vemos si el usuario está verificado documentalmente"https://host/jugar/participante/estado"
            var callConfig = {
                headers : {
                    "Content-Type": "application/json",
                },
                data : ''
            }
    
            $http.get( config.services.hostFiltro + config.services.profileUserData, callConfig )
            .then(function(e) {
                vm.user = e.data.usuarioWebDto[0];
    
                // Modificamos la fecha de nacimiento para mostrarla como la pide Selae
                if (vm.user.fechaNacimiento.search("CET") !== -1) {
                    vm.user.fechaNacimiento = $filter('date')(new Date(vm.user.fechaNacimiento.replace(/CET/, '')), "dd/MM/yyyy");
                } else {
                    vm.user.fechaNacimiento = $filter('date')(new Date(vm.user.fechaNacimiento.replace(/CEST/, '')), "dd/MM/yyyy");
                }
    

                $http.get( config.services.hostFiltro + config.services.profileUserTlf, callConfig)
                .then(function(e){
                    popupSrv.hideLoading();
                    vm.user.telefonoMovil = e.data.telefonoMovil[0];
                }), function(error) {
                    console.log("error en telefono movil", error);  
                    popupSrv.hideLoading();
                    popupSrv.showErrorPopup(requestSrv.errorHandler2(error));  
                };
                
                
            }), function(error) {
                console.log("error en datos de usuario", error);
                popupSrv.hideLoading();
                popupSrv.showErrorPopup(requestSrv.errorHandler2(error));  
            };


            $http.get( config.services.hostFiltro + config.services.profileIsVerificate, callConfig)
            .then(function(e){
                if (plugin) {
                    popupSrv.hideLoading();
                }
                if (e.data.estado === "BLOQUEADO" && e.data.motivos[0]) {
                    vm.pendienteVerificar = true;
                } else {
                    vm.pendienteVerificar = false;
                }
            }), function(error) {
                popupSrv.hideLoading();
                // error llamada inicial metemos manejador de errores comun y error si venimos del plugin mostramos popUp de error y mandamos a home
                if (plugin) {
                    popupSrv.showErrorPopup("perfilErrorVerif");
                    $state.go("app.home");
                } else {
                    popupSrv.showErrorPopup(requestSrv.errorHandler2(error));
                }
                console.log("Error en pregunta verificación de perfil", error);
            };
        };

        vm.verificateCall();

        vm.launchSDK = function() {

            // Funcion para configurar el entorno de IECISA
            var dinamicBearer = function () {
                var bearer = {
                    'pro': "03906849-2488-393c-a4e1-fa94adaea50d",
                    'int7':"8281c40c-6cb7-3962-947b-ff16c3fb84b2",
                    'int3':"3e5df3d9-51c1-3832-bb65-03fecb130155"
                }
                return bearer[selae.entorno] || bearer[pro]
            };

            var dinamicEnvironment = function() {
                var environment = {
                    'pro': "PRO",
                    'int7':"PRE",
                    'int3':"PRE"
                }
                return environment[selae.entorno] || environment[pro]
            };

                var theme = {
                    header: true,
                    isShow_logo_step_end: false,
                    primary_color: "0e3f62", // HEX
                    secondary_color: "6A6A6A",
                    tertiary_color: "000000",
                    frame1_color: "FFFFFF",
                    frame2_color: "0e3f62",
                    frame3_color: "008000",
                    title1_color: "0e3f62",
                    title2_color: "000000",
                    primary_font: "Futura-Bold", // Font Name
                    secondary_font: "OpenSans",
                    tertiary_font: "OpenSans-Semibold",
                    logo_color: "logo-color",
                    id_front: "id_front",
                    id_back: "id_back",
                    user: "user",
                    tick: "tick",
                    start_screen_label_title_textAlignment: "center",
                    start_screen_label_info_textAlignment: "center",
                    middle_screen_label_title_textAligment: "center",
                    middle_screen_label_info_textAligment: "center",
                    end_screen_label_info_textAligment: "center",
                    info_screen_label_info_textAlignment: "center",
                    end_screen_tick_rostro_color: "0e3f62",
                    button_corner_radius: 10,
                    button_border_width: 1,
                    button_color: "FFFFFF",
                    button_border_color: "0e3f62",
                    button_font_color: "0e3f62",
                    contactPhoneNumber: "900 294 105"
                };

                var textsStepInitial = {
                    step_initial_info: "VERIFICACIÓN CON DNI/NIE",
                    agreement_button_text: "El proceso suele durar 5 minutos.<br><font size='3'>Al pulsar el botón aceptas las condiciones de privacidad y datos personales disponibles desde tu perfil y das tu consentimiento para grabar el contenido de la pantalla </font><br/><br/>Si necesitas ayuda llámanos al 900 294 105.<br/><br/><b>PASOS:</b><br><br/>",
                    step_initial_obverse: "PASO 1: Foto del anverso de tu DNI/NIE",
                    step_initial_reverse: "PASO 2: Foto del reverso de tu DNI/NIE",
                    step_initial_face: "PASO 3: Video de tu rostro",
                    start_button: "COMENZAR"
                    }

                var textsStepInfo = {
                    step_info_card: "Foto del DNI/NIE por ambas caras\nColoca tu DNI/NIE con la foto hacia arriba,despues dale la vuelta para hacer la foto por la parte de atrás. ",
                    step_info_video: "Colócate delante de tu móvil mirando hacia la pantalla para que podamos grabar en video tu rostro.",
                    info_continue_button: "ABRIR CÁMARA"
                    }

                var textsCaptureCardFront = {
                    step_card_title_front: "Foto automática DNI boca arriba"
                }

                var textsCaptureCardBack = {
                    step_card_title_reverse: "Foto automática DNI boca abajo"
                }

                var textsMiddleVideo = {
                    step_middle_info: "PASO 3: Video automático de tu rostro",
                    agreement_button_text_video: "<br>Procura colocar tu rostro dentro de la guía que parece en la pantalla.<br>",
                    middle_button: "ABRIR CÁMARA"
                }

                var textsVideoCall = {
                    step_video_title: "Video automático de tu rostro"
                }

                var textsStepEnd = {
                    step_final_info: "",
                    step_final_finish: "",
                    step_final_obverse: "PASO 1: Foto del anverso de tu DNI/NIE ",
                    step_final_reverse: "PASO 2: Foto del reverso de tu DNI/NIE ",
                    step_final_face: "PASO 3: Video de tu rostro",
                    agreement_final_text: "<b> ¡GRACIAS! Vuelve a revisar tus datos personales pasados unos minutos para confirmar que el intento de verificación ha tenido éxito. Si no es así, te lo notificaremos en tu buzón de mensajes. Hemos capturado correctamente toda la información:</b>",
                    end_button: "CONTINUAR"
                    }

                var textsError = {
                    error_button: "ABRIR CÁMARA"
                }

                var texts = {
                    textsStepInitial: textsStepInitial,
                    textsStepInfo: textsStepInfo,
                    textsCaptureCardFront: textsCaptureCardFront,
                    textsCaptureCardBack: textsCaptureCardBack,
                    textsMiddleVideo: textsMiddleVideo,
                    textsVideoCall: textsVideoCall,
                    textsStepEnd: textsStepEnd,
                    textsError: textsError
                };
                
                var config = {
                    upload_check: true,
                    bearer: dinamicBearer(),
                    clean_view_stack: true,
                    identifiers: ["ESP"],
                    environment: dinamicEnvironment(),
                    texts: texts,
                    theme: theme,
                    flow: ["initial", "info_capture_card", "capture_card_front", "capture_card_reverse", "middle", "info_capture_face", "capture_face_call", "final"],
                    show_card_frame: false,
                    capture_rotation: false,
                    show_cancel_error: false,
                    step_max_retries: 3,
                    step_max_timeout: 30,
                    min_bitrate: 500,
                    videoDuration: 12.0,
                    videoMessages: false
                };
        
                
            console.log("vamos a llamar al plugin de verificacion documental");
            startSdkDob.start({ 'config': config }, { 'uid': vm.DoBInfo.userID }, {'tokenDob':vm.DoBInfo.tokenDoB},
                function () {
                    console.log("Entramos por callback de exito.");
                    var delayTime = $rootScope.selae.properties.perfilTimer || 1000;
                    console.log("delay time= ",delayTime);
                    popupSrv.showLoading('Comprobando datos');
                    setTimeout( function() {
                        vm.verificateCall(true); 
                    }, delayTime);
                    console.log("We finish success!!");
                },
                function (error) {
                    console.log('Entramos por callback de Error.');
                    console.log(error);
                    popupSrv.showErrorPopup('perfilErrorPlugin', null, $filter('translate')('perfilErrorPluginNoFotoURL'));
                },
                {});
        }

        vm.verificate = function() {
            // Este dato está an local storage porque es uno por sesión, no tiene que persistir entre sesiones
            var participanteId = vm.user.identificador;
            var params = { "tipoFlujo": "2",
                            "participanteId": participanteId
                        };
            $http.post( config.services.host + config.services.profileVerify, params)
            .then(function (e) {
                console.log(e)
                vm.DoBInfo = e.data.response;
                vm.launchSDK();
                
            }, function(error) {
                console.log("Error en recopilacion de datos para verificación de perfil",error)
            }); 
        }

        vm.noLink = $rootScope.selae.properties.perfilNoFotoURL || 'false';

        vm.noFoto = function() {
            window.open($filter("translate")("perfilNoFotoURL"), '_system', 'location=no');
        }
}
